==> phoenix-0.1.7.tar.gz: phoenix-0.1.7/scripts/history.tcl <==
################################################################
# Modifications beyond tkWWW 0.9 are Copyright 1993, 1994 by
# The University of Chicago Biological Sciences Division, Academic Computing
# Philip Stylianos
# Lee Newberg
################################################################

## history.tcl: history for Phoenix user interface
## ==============
## Copyright (C) 1993
## Global Network Academy
## MacVicar Institute for Educational Software Development
##
## See the file COPYRIGHT for conditions

proc tkW3HistoryInitialize {} {
    global tkW3HistoryList tkW3HistoryStackList phxW3HistoryListIndex

    # A list of pages already visited.  For the History menu.
    set tkW3HistoryList {}

    # If the current page is already on the history list, this is its index.
    set phxW3HistoryListIndex none

    # A stack of pages visited.  For the tkW3NavigateBacktrack command.
    set tkW3HistoryStackList {}
}

# phxW3HistoryPush: Add an entry to the top of the History Stack
# unless it is identical to the current top.  The stack is used
# for tkW3NavigateBacktrack.

proc phxW3HistoryPush {title address scroll_pos} {
    global tkW3HistoryStackList

    set entry [phxW3HistoryBindObject $title $address $scroll_pos]
    if {$entry == {}} {return}
    if {$entry != [lindex $tkW3HistoryStackList [expr [llength $tkW3HistoryStackList]-1 ] ]} {
	lappend tkW3HistoryStackList $entry
    }
}

# tkW3HistoryPop: Remove and return the top entry on the History
# Stack.

proc tkW3HistoryPop {} {
    global tkW3HistoryStackList tkW3HistoryList
    set index [expr {[llength $tkW3HistoryStackList]-1}] 
    set return_string [lindex $tkW3HistoryStackList $index]
    incr index -1
    set tkW3HistoryStackList [lrange $tkW3HistoryStackList 0 $index]
    
    return $return_string
}

# phxW3HistoryBindObject: Create a canonical item for storing on
# the History Stack.

proc phxW3HistoryBindObject {title address scroll_pos} {
    set address [string trim $address]
    set title [string trim $title]
    if {$address == {}} { return {} }
    if {$title == {}} { set title $address }
    return [list $title $address $scroll_pos]
}

proc phxW3HistoryRecordAndPush {title address scroll_pos} {
	phxW3HistoryRecord $title $address $scroll_pos
	phxW3HistoryPush $title $address $scroll_pos
}

# phxW3HistoryRecord: Store the supplied information on the
# History List for access via the History Menu.

proc phxW3HistoryRecord {title address scroll_pos} {
    global tkW3HistoryList phxW3HistoryListIndex

    set entry [phxW3HistoryBindObject $title $address $scroll_pos]
    if {$entry == {}} {return}

    if {$phxW3HistoryListIndex != "none"} {
	set tkW3HistoryList [lreplace $tkW3HistoryList \
	    $phxW3HistoryListIndex $phxW3HistoryListIndex $entry]
	phxW3MenuChangeNodeMenu .menu.history.m $phxW3HistoryListIndex $entry
	.menu.history.m entryconfigure $phxW3HistoryListIndex -state normal
	set phxW3HistoryListIndex none
    } else {
	lappend tkW3HistoryList $entry
	tkW3MenuAddToNodeMenu .menu.history.m $entry
    }
}

proc phxW3HistoryInsensitize {title address scroll_pos} {
    global tkW3HistoryList phxW3HistoryListIndex

    set entry [phxW3HistoryBindObject $title $address $scroll_pos]
    if {$entry == {}} {return}

    set index [lsearch $tkW3HistoryList $entry]
    if {$index >= 0} {
	.menu.history.m entryconfigure $index -state disabled
	set phxW3HistoryListIndex $index
    }
}

==> phoenix-0.1.8.tar.gz: phoenix-0.1.8/scripts/history.tcl <==
################################################################
# Modifications beyond tkWWW 0.9 are Copyright 1993, 1994 by
# The University of Chicago Biological Sciences Division, Academic Computing
# Philip Stylianos
# Lee Newberg
# Greg Haygood
################################################################

## history.tcl: history for Phoenix user interface
## ==============
## Copyright (C) 1993
## Global Network Academy
## MacVicar Institute for Educational Software Development
##
## See the file COPYRIGHT for conditions

proc tkW3HistoryInitialize {} {
    global tkW3HistoryList tkW3HistoryBackwardStack tkW3HistoryForwardStack phxW3HistoryListIndex 

    # A list of pages already visited.  For the History menu.
    set tkW3HistoryList {}

    # If the current page is already on the history list, this is its index.
    set phxW3HistoryListIndex none

    # A stack of pages visited.  For the tkW3NavigateBacktrack and 
    # tkW3historyForward commands.
    set tkW3HistoryBackwardStack {}
    set tkW3HistoryForwardStack {}
}

# phxW3HistoryPush: Add an entry to the top of the History Stack
# unless it is identical to the current top.  The stack is used
# for tkW3NavigateBacktrack.

proc phxW3HistoryPush {title address scroll_pos} {
    global tkW3HistoryBackwardStack

    set entry [phxW3HistoryBindObject $title $address $scroll_pos]
    if {$entry == {}} {return}
    if {$entry != [lindex $tkW3HistoryBackwardStack [expr [llength $tkW3HistoryBackwardStack]-1 ] ]} {
	lappend tkW3HistoryBackwardStack $entry
    }
}

# tkW3HistoryForwardPop: Return the top entry on the HistoryForward Stack, 
# and append it to tkW3HistoryBackwardStack.

proc tkW3HistoryForwardPop {} {
    global tkW3HistoryForwardStack tkW3HistoryBackwardStack

    set entry [phxW3HistoryBindObject [tkW3OutputGetTitle] \
	[tkW3OutputGetAddress] [tkW3OutputGetScrollPosition]]
    set index [expr {[llength $tkW3HistoryForwardStack]-1}]
    set return_string [lindex $tkW3HistoryForwardStack $index]
    lappend tkW3HistoryBackwardStack $entry
    set tkW3HistoryForwardStack \
	[lreplace $tkW3HistoryForwardStack $index $index]	

    return $return_string
}

# tkW3HistoryBackwardPop: Return the top entry on the History Stack, adding 
# it to tkW3HistoryForwardStack.

proc tkW3HistoryBackwardPop {} {
    global tkW3HistoryBackwardStack tkW3HistoryForwardStack
    
    set entry [phxW3HistoryBindObject [tkW3OutputGetTitle] \
	[tkW3OutputGetAddress] [tkW3OutputGetScrollPosition]]
    set index [expr {[llength $tkW3HistoryBackwardStack]-1}]
    set return_string [lindex $tkW3HistoryBackwardStack $index]
    lappend tkW3HistoryForwardStack $entry
    set tkW3HistoryBackwardStack [lreplace $tkW3HistoryBackwardStack $index $index] 

    return $return_string
}

# phxW3HistoryBindObject: Create a canonical item for storing on
# the History Stack.

proc phxW3HistoryBindObject {title address scroll_pos} {
    set address [string trim $address]
    set title [string trim $title]
    if {$address == {}} { return {} }
    if {$title == {}} { set title $address }
    return [list $title $address $scroll_pos]
}

proc phxW3HistoryRecordAndPush {title address scroll_pos} {
	phxW3HistoryRecord $title $address $scroll_pos
	phxW3HistoryPush $title $address $scroll_pos
}

# phxW3HistoryRecord: Store the supplied information on the
# History List for access via the History Menu.

proc phxW3HistoryRecord {title address scroll_pos} {
    global tkW3HistoryList phxW3HistoryListIndex

    set entry [phxW3HistoryBindObject $title $address $scroll_pos]
    if {$entry == {}} {return}

    if {$phxW3HistoryListIndex != "none"} {
	set tkW3HistoryList [lreplace $tkW3HistoryList \
	    $phxW3HistoryListIndex $phxW3HistoryListIndex $entry]
	phxW3MenuChangeNodeMenu .menu.history.m $phxW3HistoryListIndex $entry
	.menu.history.m entryconfigure $phxW3HistoryListIndex -state normal
	set phxW3HistoryListIndex none
    } else {
	lappend tkW3HistoryList $entry
	tkW3MenuAddToNodeMenu .menu.history.m $entry
    }
}

proc phxW3HistoryInsensitize {title address scroll_pos} {
    global tkW3HistoryList phxW3HistoryListIndex

    set entry [phxW3HistoryBindObject $title $address $scroll_pos]
    if {$entry == {}} {return}

    set index [lsearch $tkW3HistoryList $entry]
    if {$index >= 0} {
	.menu.history.m entryconfigure $index -state disabled
	set phxW3HistoryListIndex $index
    }
}
